@@ -5,14 +5,22 @@ import (
 	"rare/pkg/readahead"
 )
 
-func unbatchMatches(c <-chan []Match) []Match {
-	matches := make([]Match, 0)
+func unbatchMatches[T any](c <-chan []T) []T {
+	matches := make([]T, 0)
 	for batch := range c {
 		matches = append(matches, batch...)
 	}
 	return matches
 }
 
+func matchSetToString(matches []Match) []string {
+	ret := make([]string, len(matches))
+	for i, match := range matches {
+		ret[i] = match.Extracted
+	}
+	return ret
+}
+
 func convertReaderToBatches(sourceName string, reader io.Reader, batchSize int) <-chan InputBatch {
 	out := make(chan InputBatch)
 	ra := readahead.NewImmediate(reader, 128*1024)
