@@ -6,8 +6,9 @@ import "sync"
 // Technically can accept objects it didn't create, though that's not good as will pollute the size
 // operates in non-blocking mode (it will create a new object if it doesn't have one readily available)
 type ObjectPool[T any] struct {
-	pool []*T
-	m    sync.Mutex
+	pool  []*T
+	newer func() *T
+	m     sync.Mutex
 }
 
 // Create an object pool of an initial size. May grow later
@@ -18,7 +19,8 @@ func NewObjectPool[T any](size int) *ObjectPool[T] {
 // Create an object pool with a custom object initializer
 func NewObjectPoolEx[T any](size int, newer func() *T) *ObjectPool[T] {
 	ret := &ObjectPool[T]{
-		pool: make([]*T, size),
+		pool:  make([]*T, size),
+		newer: newer,
 	}
 	for i := 0; i < size; i++ {
 		ret.pool[i] = newer()
@@ -31,7 +33,7 @@ func (s *ObjectPool[T]) Get() (ret *T) {
 	defer s.m.Unlock()
 
 	if len(s.pool) == 0 {
-		return new(T)
+		return s.newer()
 	}
 
 	end := len(s.pool) - 1
